@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: opts.c,v 1.8 2000/01/12 16:44:25 ezk Exp $
+ * $Id: opts.c,v 1.8.2.3 2000/11/22 10:13:37 ezk Exp $
  *
  */
 
@@ -116,6 +116,7 @@ static char uid_str[12], gid_str[12];
 char *opt_uid = uid_str;
 char *opt_gid = gid_str;
 static char *vars[8];
+static char *literal_dollar = "$"; /* ${dollar}: a literal '$' in maps */
 
 /*
  * GLOBALS
@@ -129,7 +130,7 @@ struct am_opts fs_static;	/* copy of the options to play with */
  */
 static struct opt opt_fields[] = {
   /* Name and length.
-	Option str.		Selector str.	boolean fxn.	flags */
+	Option str.		Selector str.	boolean fxn.	case sensitive */
   { S("opts"),
        &fs_static.opt_opts,	0,		0, 		FALSE	},
   { S("host"),
@@ -156,8 +157,6 @@ static struct opt opt_fields[] = {
 	&fs_static.opt_dev,	0,		0,		FALSE	},
   { S("pref"),
 	&fs_static.opt_pref,	0,		0,		FALSE	},
-  { S("autopref"),
-	&fs_static.opt_autopref,0,		0,		FALSE	},
   { S("path"),
 	0,			&opt_path,	0,		FALSE	},
   { S("autodir"),
@@ -202,6 +201,7 @@ static struct opt opt_fields[] = {
 	0,			&opt_dkey,	0,		FALSE	},
   { S("key."),
 	0,			&opt_keyd,	0,		FALSE	},
+  /* XXX: should maptype really be a variable? I think selector. -Erez */
   { S("maptype"),
 	&fs_static.opt_maptype,	0,		0,		FALSE	},
   { S("cachedir"),
@@ -212,6 +212,8 @@ static struct opt opt_fields[] = {
 	0,			&opt_uid,	0,		FALSE	},
   { S("gid"),
 	0,			&opt_gid,	0, 		FALSE	},
+  { S("dollar"),
+	&literal_dollar,	0,		0,		FALSE	},
   { S("var0"),
 	&vars[0],		0,		0,		FALSE	},
   { S("var1"),
@@ -314,7 +316,7 @@ backslash(char **p)
   if (**p == '\\') {
     (*p)++;
     switch (**p) {
-    case 'a':
+    case 'g':
       c = '\007';		/* Bell */
       break;
     case 'b':
@@ -867,7 +869,7 @@ normalize_slash(char *p)
 static void
 expand_op(opt_apply *p, int sel_p)
 {
-  static char expand_error[] = "No space to expand \"%s\"";
+  static const char expand_error[] = "No space to expand \"%s\"";
   char expbuf[MAXPATHLEN + 1];
   char nbuf[NLEN + 1];
   char *ep = expbuf;
