@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1999 Erez Zadok
+ * Copyright (c) 1997-2000 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: hlfsd.c,v 1.3 1999/01/10 21:54:32 ezk Exp $
+ * $Id: hlfsd.c,v 1.7.2.1 2000/11/22 10:13:41 ezk Exp $
  *
  * HLFSD was written at Columbia University Computer Science Department, by
  * Erez Zadok <ezk@cs.columbia.edu> and Alexander Dupuy <dupuy@cs.columbia.edu>
@@ -95,11 +95,11 @@ nfstime startup;
 u_short nfs_port;
 
 /* symbol must be available always */
-#ifdef MOUNT_TABLE_ON_FILE
+#ifdef MNTTAB_FILE_NAME
 char *mnttab_file_name = MNTTAB_FILE_NAME;
-#else /* not MOUNT_TABLE_ON_FILE */
+#else /* not MNTTAB_FILE_NAME */
 char *mnttab_file_name = NULL;
-#endif /* not MOUNT_TABLE_ON_FILE */
+#endif /* not MNTTAB_FILE_NAME */
 
 /* forward declarations */
 void hlfsd_going_down(int rc);
@@ -935,14 +935,19 @@ fatal(char *mess)
       lessmess[messlen - 4] = '\0';
 
       if (errno < sys_nerr)
-	fprintf(stderr, "%s: %s: %s\n", am_get_progname(),
-		lessmess, sys_errlist[errno]);
+	fprintf(stderr, "%s: %s: %s\n", am_get_progname(), lessmess,
+#ifdef HAVE_STRERROR
+		strerror(errno)
+#else /* not HAVE_STRERROR */
+		sys_errlist[errno]
+#endif /* not HAVE_STRERROR */
+		);
       else
 	fprintf(stderr, "%s: %s: Error %d\n",
 		am_get_progname(), lessmess, errno);
     }
   }
-  plog(XLOG_FATAL, mess);
+  plog(XLOG_FATAL, "%s", mess);
 
   hlfsd_going_down(1);
 }
