@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1999 Erez Zadok
+ * Copyright (c) 1997-2000 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: am_defs.h,v 1.4 1999/01/13 23:31:20 ezk Exp $
+ * $Id: am_defs.h,v 1.15.2.4 2000/12/02 23:29:12 ib42 Exp $
  *
  */
 
@@ -321,7 +321,7 @@ extern int errno;
 #endif /* HAVE_SYS_MNTENT_H */
 
 /*
- * Actions to take if <ndbm.h> exists.
+ * Actions to take if <ndbm.h> or <db1/ndbm.h> exist.
  * Should be included before <rpcsvc/yp_prot.h> because on some systems
  * like Linux, it also defines "struct datum".
  */
@@ -331,6 +331,14 @@ extern int errno;
 /* ensure that struct datum is not included again from <rpcsvc/yp_prot.h> */
 #  define DATUM
 # endif /* not DATUM */
+#else /* not HAVE_NDBM_H */
+# ifdef HAVE_DB1_NDBM_H
+#  include <db1/ndbm.h>
+#  ifndef DATUM
+/* ensure that struct datum is not included again from <rpcsvc/yp_prot.h> */
+#   define DATUM
+#  endif /* not DATUM */
+# endif /* HAVE_DB1_NDBM_H */
 #endif /* HAVE_NDBM_H */
 
 /*
@@ -341,19 +349,19 @@ extern int errno;
 #endif /* HAVE_NET_ERRNO_H */
 
 /*
- * Actions to take if <net/if.h> exists.
+ * Actions to take if <net/route.h> exists.
  */
 #ifdef HAVE_NET_ROUTE_H
 # include <net/route.h>
 #endif /* HAVE_NET_ROUTE_H */
 
 /*
- * Actions to take if <net/if.h> exists.
+ * Actions to take if <sys/mbuf.h> exists.
  */
 #ifdef HAVE_SYS_MBUF_H
 # include <sys/mbuf.h>
 /*
- * OSF4 (DU-4.0) defines m_next and m_data also in <sys/mount> so I must
+ * OSF4 (DU-4.0) defines m_next and m_data also in <sys/mount.h> so I must
  # undefine them here to avoid conflicts.
  */
 # ifdef m_next
@@ -363,7 +371,7 @@ extern int errno;
 #  undef m_data
 # endif /* m_data */
 /*
- * AIX 3 defines MFREE and m_flags also in <sys/mount>.
+ * AIX 3 defines MFREE and m_flags also in <sys/mount.h>.
  */
 # ifdef m_flags
 #  undef m_flags
@@ -485,11 +493,13 @@ struct ypall_callback;
 
 /*
  * Actions to take if <linux/fs.h> exists.
+ * There is no point in including this on a glibc2 system,
+ * we're only asking for trouble
  */
-#ifdef HAVE_LINUX_FS_H
+#if defined HAVE_LINUX_FS_H && (!defined __GLIBC__ || __GLIBC__ < 2)
 /*
- * There's a conflict of definitions on redhat alpha linux between
- * <netinet/in.h> and <linux/fs.h>.
+ * There are various conflicts in definitions between RedHat Linux, newer
+ * 2.2 kernels, and <netinet/in.h> and <linux/fs.h>.
  */
 # ifdef HAVE_SOCKETBITS_H
 /* conflicts with <socketbits.h> */
@@ -503,26 +513,70 @@ struct ypall_callback;
 #  undef BLKRRPART
 #  undef MS_MGC_VAL
 #  undef MS_RMT_MASK
+#  if defined(__GLIBC__) && __GLIBC__ >= 2
 /* conflicts with <waitflags.h> */
-#  undef WNOHANG
-#  undef WUNTRACED
+#   undef WNOHANG
+#   undef WUNTRACED
+#  endif /* defined(__GLIBC__) && __GLIBC__ >= 2 */
 /* conflicts with <statfsbuf.h> */
 #  define _SYS_STATFS_H
 # endif /* HAVE_SOCKETBITS_H */
+
+# ifdef _SYS_WAIT_H
+#  if defined(__GLIBC__) && __GLIBC__ >= 2
+/* conflicts with <bits/waitflags.h> (RedHat/Linux 6.0 and kernels 2.2 */
+#   undef WNOHANG
+#   undef WUNTRACED
+#  endif /* defined(__GLIBC__) && __GLIBC__ >= 2 */
+# endif /* _SYS_WAIT_H */
+
 # ifdef HAVE_LINUX_POSIX_TYPES_H
 #  include <linux/posix_types.h>
 # endif /* HAVE_LINUX_POSIX_TYPES_H */
 # ifndef _LINUX_BYTEORDER_GENERIC_H
 #  define _LINUX_BYTEORDER_GENERIC_H
 # endif /* _LINUX_BYTEORDER_GENERIC_H */
-/* conflicts with <sys/mount.h> in 2.1 kernels */
+/* conflicts with <sys/mount.h> in 2.[12] kernels */
 # ifdef _SYS_MOUNT_H
-#  ifdef BLOCK_SIZE
-#   undef BLOCK_SIZE
-#  endif /* BLOCK_SIZE */
+#  undef BLKFLSBUF
+#  undef BLKGETSIZE
+#  undef BLKRAGET
+#  undef BLKRASET
+#  undef BLKROGET
+#  undef BLKROSET
+#  undef BLKRRPART
+#  undef BLOCK_SIZE
+#  undef MS_MANDLOCK
+#  undef MS_MGC_VAL
+#  undef MS_NOATIME
+#  undef MS_NODEV
+#  undef MS_NODIRATIME
+#  undef MS_NOEXEC
+#  undef MS_NOSUID
+#  undef MS_RDONLY
+#  undef MS_REMOUNT
+#  undef MS_RMT_MASK
+#  undef MS_SYNCHRONOUS
+#  undef S_APPEND
+#  undef S_IMMUTABLE
+/* conflicts with <statfsbuf.h> */
+#  define _SYS_STATFS_H
 # endif /* _SYS_MOUNT_H */
+# ifndef _LINUX_STRING_H_
+#  define _LINUX_STRING_H_
+# endif /* not _LINUX_STRING_H_ */
+# ifdef HAVE_LINUX_KDEV_T_H
+#  define __KERNEL__
+#  include <linux/kdev_t.h>
+#  undef __KERNEL__
+# endif /* HAVE_LINUX_KDEV_T_H */
+# ifdef HAVE_LINUX_LIST_H
+#  define __KERNEL__
+#  include <linux/list.h>
+#  undef __KERNEL__
+# endif /* HAVE_LINUX_LIST_H */
 # include <linux/fs.h>
-#endif /* HAVE_LINUX_FS_H */
+#endif /* HAVE_LINUX_FS_H && (!__GLIBC__ || __GLIBC__ < 2) */
 
 #ifdef HAVE_CDFS_CDFS_MOUNT_H
 # include <cdfs/cdfs_mount.h>
@@ -594,7 +648,7 @@ struct ypall_callback;
 # include <nfs/mount.h>
 #endif /* HAVE_NFS_MOUNT_H */
 #ifdef HAVE_NFS_NFS_MOUNT_H_off
-/* broken on nexttep3 (includes non-existing headers) */
+/* broken on nextstep3 (includes non-existing headers) */
 # include <nfs/nfs_mount.h>
 #endif /* HAVE_NFS_NFS_MOUNT_H */
 #ifdef HAVE_NFS_PATHCONF_H
@@ -610,6 +664,10 @@ struct ypall_callback;
 # include <sys/fs/nfs_clnt.h>
 #endif /* HAVE_SYS_FS_NFS_CLNT_H */
 #ifdef HAVE_LINUX_NFS_MOUNT_H
+# define _LINUX_NFS_H
+# define _LINUX_NFS2_H
+# define _LINUX_NFS_FS_H
+# define _LINUX_IN_H
 # include <linux/nfs_mount.h>
 #endif /* HAVE_LINUX_NFS_MOUNT_H */
 
@@ -719,6 +777,12 @@ struct sockaddr_dl;
 #ifdef HAVE_SYS_FS_UFS_MOUNT_H
 # include <sys/fs/ufs_mount.h>
 #endif /* HAVE_SYS_FS_UFS_MOUNT_H */
+#ifdef	HAVE_UFS_UFS_UFSMOUNT_H_off
+# error do not include this file here because on netbsd/openbsd it
+# error causes errors with other header files.  Instead, add it to the
+# error specific conf/nfs_prot_*.h file.
+# include <ufs/ufs/ufsmount.h>
+#endif	/* HAVE_UFS_UFS_UFSMOUNT_H */
 
 /*
  * Actions to take if <sys/fs/efs_clnt.h> exists.
@@ -1297,6 +1361,10 @@ extern caddr_t sbrk(int incr);
 extern int seteuid(uid_t euid);
 #endif /* not defined(HAVE_SETEUID) && !defined(HAVE_EXTERN_SETEUID) */
 
+#if defined(HAVE_SETITIMER) && !defined(HAVE_EXTERN_SETITIMER)
+extern int setitimer(int, struct itimerval *, struct itimerval *);
+#endif /* defined(HAVE_SETITIMER) && !defined(HAVE_EXTERN_SETITIMER) */
+
 #ifndef HAVE_EXTERN_STRCASECMP
 /*
  * define this extern even if function does not exist, for it will
@@ -1329,11 +1397,14 @@ extern u_int ualarm(u_int usecs, u_int interval);
 extern int wait3(int *statusp, int options, struct rusage *rusage);
 #endif /* defined(HAVE_WAIT3) && !defined(HAVE_EXTERN_WAIT3) */
 
+#if defined(HAVE_VSNPRINTF) && !defined(HAVE_EXTERN_VSNPRINTF)
+extern int vsnprintf(char *, int, const char *, ...);
+#endif /* defined(HAVE_VSNPRINTF) && !defined(HAVE_EXTERN_VSNPRINTF) */
+
 #ifndef HAVE_EXTERN_XDR_OPAQUE_AUTH
 extern bool_t xdr_opaque_auth(XDR *xdrs, struct opaque_auth *auth);
 #endif /* not HAVE_EXTERN_XDR_OPAQUE_AUTH */
 
-
 /****************************************************************************/
 /*
  * amd-specific header files.
