@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1999 Erez Zadok
+ * Copyright (c) 1997-2000 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mount_fs.c,v 1.4 1999/01/15 17:14:29 ezk Exp $
+ * $Id: mount_fs.c,v 1.11.2.3 2000/12/02 23:29:13 ib42 Exp $
  *
  */
 
@@ -105,6 +105,14 @@ struct opt_tab mnt_flags[] =
   {MNTTAB_OPT_OVERLAY, MNT2_GEN_OPT_OVERLAY},
 #endif /* defined(MNT2_GEN_OPT_OVERLAY) && defined(MNTTAB_OPT_OVERLAY) */
 
+#if defined(MNT2_NFS_OPT_PROPLIST) && defined(MNTTAB_OPT_PROPLIST)
+  {MNTTAB_OPT_PROPLIST, MNT2_NFS_OPT_PROPLIST},
+#endif /* defined(MNT2_NFS_OPT_PROPLIST) && defined(MNTTAB_OPT_PROPLIST) */
+
+#if defined(MNT2_NFS_OPT_NONLM) && defined(MNTTAB_OPT_NOLOCK)
+  {MNTTAB_OPT_NOLOCK, MNT2_NFS_OPT_NONLM},
+#endif /* defined(MNT2_NFS_OPT_NONLM) && defined(MNTTAB_OPT_NOLOCK) */
+
   {0, 0}
 };
 
@@ -156,6 +164,9 @@ compute_automounter_mount_flags(mntent_t *mntp)
 #ifdef MNT2_GEN_OPT_IGNORE
   flags |= MNT2_GEN_OPT_IGNORE;
 #endif /* not MNT2_GEN_OPT_IGNORE */
+#ifdef MNT2_GEN_OPT_AUTOMNTFS
+  flags |= MNT2_GEN_OPT_AUTOMNTFS;
+#endif /* not MNT2_GEN_OPT_AUTOMNTFS */
 
   return flags;
 }
@@ -174,14 +185,10 @@ mount_fs(mntent_t *mnt, int flags, caddr_t mnt_data, int retry, MTYPE_TYPE type,
   char optsbuf[48];
 # endif /* defined(MNTTAB_OPT_DEV) || (defined(HAVE_FS_NFS3) && defined(MNTTAB_OPT_VERS)) || defined(MNTTAB_OPT_PROTO) */
 #endif /* MOUNT_TABLE_ON_FILE */
-#ifdef DEBUG
-  char buf[80];			/* buffer for sprintf */
-#endif /* DEBUG */
 
 #ifdef DEBUG
-  sprintf(buf, "%s%s%s",
-	  "%s fstype ", MTYPE_PRINTF_TYPE, " (%s) flags %#x (%s)");
-  dlog(buf, mnt->mnt_dir, type, mnt->mnt_type, flags, mnt->mnt_opts);
+  dlog("%s fstype " MTYPE_PRINTF_TYPE " (%s) flags %#x (%s)",
+       mnt->mnt_dir, type, mnt->mnt_type, flags, mnt->mnt_opts);
 #endif /* DEBUG */
 
 again:
@@ -381,6 +388,9 @@ compute_nfs_args(nfs_args_t *nap, mntent_t *mntp, int genflags, struct sockaddr_
 # ifdef MNT2_NFS_OPT_NFSV3
     nap->flags |= MNT2_NFS_OPT_NFSV3;
 # endif /* MNT2_NFS_OPT_NFSV3 */
+# ifdef MNT2_NFS_OPT_VER3
+    nap->flags |= MNT2_NFS_OPT_VER3;
+# endif /* MNT2_NFS_OPT_VER3 */
   } else
 #endif /* HAVE_FS_NFS3 */
     NFS_FH_DREF(nap->NFS_FH_FIELD, &(fhp->v2.fhs_fh));
@@ -642,6 +652,12 @@ compute_nfs_args(nfs_args_t *nap, mntent_t *mntp, int genflags, struct sockaddr_
      * Either turn on the "allow interrupts" option, or
      * turn off the "disallow interrupts" option"
      */
+# ifdef MNT2_NFS_OPT_INTR
+    nap->flags |= MNT2_NFS_OPT_INTR;
+# endif /* MNT2_NFS_OPT_INTR */
+# ifdef MNT2_NFS_OPT_NOINTR
+    nap->flags &= ~MNT2_NFS_OPT_NOINTR;
+# endif /* MNT2_NFS_OPT_NOINTR */
 # ifdef MNT2_NFS_OPT_INT
     nap->flags |= MNT2_NFS_OPT_INT;
 # endif /* MNT2_NFS_OPT_INT */
@@ -687,6 +703,11 @@ compute_nfs_args(nfs_args_t *nap, mntent_t *mntp, int genflags, struct sockaddr_
   }
 #endif /* MNT2_NFS_OPT_POSIX && MNTTAB_OPT_POSIX */
 
+#if defined(MNT2_NFS_OPT_PROPLIST) && defined(MNTTAB_OPT_PROPLIST)
+  if (hasmntopt(mntp, MNTTAB_OPT_PROPLIST) != NULL)
+    nap->flags |= MNT2_NFS_OPT_PROPLIST;
+#endif /* defined(MNT2_NFS_OPT_PROPLIST) && defined(MNTTAB_OPT_PROPLIST) */
+
 #if defined(MNT2_NFS_OPT_MAXGRPS) && defined(MNTTAB_OPT_MAXGROUPS)
   nap->maxgrouplist = hasmntval(mntp, MNTTAB_OPT_MAXGROUPS);
   if (nap->maxgrouplist != NULL)
@@ -728,7 +749,8 @@ compute_automounter_nfs_args(nfs_args_t *nap, mntent_t *mntp)
 #endif /* MNT2_NFS_OPT_SYMTTL */
 
   /*
-   * This completes the flags for the HIDE_MOUNT_TYPE code above.
+   * This completes the flags for the HIDE_MOUNT_TYPE  code in the
+   * mount_amfs_toplvl() function in amd/amfs_toplvl.c.
    * Some systems don't have a mount type, but a mount flag.
    */
 #ifdef MNT2_NFS_OPT_AUTO
@@ -737,6 +759,9 @@ compute_automounter_nfs_args(nfs_args_t *nap, mntent_t *mntp)
 #ifdef MNT2_NFS_OPT_IGNORE
   nap->flags |= MNT2_NFS_OPT_IGNORE;
 #endif /* MNT2_NFS_OPT_IGNORE */
+#ifdef MNT2_GEN_OPT_AUTOMNTFS
+  nap->flags |= MNT2_GEN_OPT_AUTOMNTFS;
+#endif /* not MNT2_GEN_OPT_AUTOMNTFS */
 
 #ifdef MNT2_NFS_OPT_DUMBTIMR
   /*
@@ -769,6 +794,13 @@ compute_automounter_nfs_args(nfs_args_t *nap, mntent_t *mntp)
   nap->flags |= MNT2_NFS_OPT_ACDIRMIN | MNT2_NFS_OPT_ACDIRMAX;
 # endif /* defined(MNT2_NFS_OPT_ACDIRMIN) && defined(MNT2_NFS_OPT_ACDIRMAX) */
 #endif /* not MNT2_NFS_OPT_NOAC */
+  /*
+   * Provide a slight bit more security by requiring the kernel to use
+   * reserved ports.
+   */
+#ifdef MNT2_NFS_OPT_RESVPORT
+  nap->flags |= MNT2_NFS_OPT_RESVPORT;
+#endif /* MNT2_NFS_OPT_RESVPORT */
 }
 
 
@@ -841,7 +873,7 @@ print_nfs_args(const nfs_args_t *nap, u_long nfs_version)
   plog(XLOG_DEBUG, "NA->addr {sockaddr_in} (len=%d) = \"%s\"",
        (int) sizeof(struct sockaddr_in),
        get_hex_string(sizeof(struct sockaddr_in), (const char *)sap));
-#ifdef HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN_off
+#ifdef HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN
   plog(XLOG_DEBUG, "NA->addr.sin_len = \"%d\"", sap->sin_len);
 #endif /* HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN */
   plog(XLOG_DEBUG, "NA->addr.sin_family = \"%d\"", sap->sin_family);
@@ -851,6 +883,10 @@ print_nfs_args(const nfs_args_t *nap, u_long nfs_version)
 #endif /* not HAVE_TRANSPORT_TYPE_TLI */
 
   plog(XLOG_DEBUG, "NA->hostname = \"%s\"", nap->hostname ? nap->hostname : "null");
+#ifdef HAVE_FIELD_NFS_ARGS_T_NAMLEN
+  plog(XLOG_DEBUG, "NA->namlen = %d", nap->namlen);
+#endif /* HAVE_FIELD_NFS_ARGS_T_NAMLEN */
+
 #ifdef MNT2_NFS_OPT_FSNAME
   plog(XLOG_DEBUG, "NA->fsname = \"%s\"", nap->fsname ? nap->fsname : "null");
 #endif /* MNT2_NFS_OPT_FSNAME */
@@ -877,24 +913,27 @@ print_nfs_args(const nfs_args_t *nap, u_long nfs_version)
   plog(XLOG_DEBUG, "NA->sotype = %d", nap->sotype);
 #endif /* HAVE_FIELD_NFS_ARGS_T_SOTYPE */
 #ifdef HAVE_FIELD_NFS_ARGS_T_PROTO
-  plog(XLOG_DEBUG, "NA->proto = %d", nap->proto);
+  plog(XLOG_DEBUG, "NA->proto = %d", (int) nap->proto);
 #endif /* HAVE_FIELD_NFS_ARGS_T_PROTO */
 #ifdef HAVE_FIELD_NFS_ARGS_T_VERSION
   plog(XLOG_DEBUG, "NA->version = %d", nap->version);
 #endif /* HAVE_FIELD_NFS_ARGS_T_VERSION */
 
-  plog(XLOG_DEBUG, "NA->flags = 0x%x", nap->flags);
+  plog(XLOG_DEBUG, "NA->flags = 0x%x", (int) nap->flags);
 
-  plog(XLOG_DEBUG, "NA->rsize = %d", nap->rsize);
-  plog(XLOG_DEBUG, "NA->wsize = %d", nap->wsize);
-  plog(XLOG_DEBUG, "NA->timeo = %d", nap->timeo);
-  plog(XLOG_DEBUG, "NA->retrans = %d", nap->retrans);
+  plog(XLOG_DEBUG, "NA->rsize = %d", (int) nap->rsize);
+  plog(XLOG_DEBUG, "NA->wsize = %d", (int) nap->wsize);
+#ifdef HAVE_FIELD_NFS_ARGS_T_BSIZE
+  plog(XLOG_DEBUG, "NA->bsize = %d", nap->bsize);
+#endif /* HAVE_FIELD_NFS_ARGS_T_BSIZE */
+  plog(XLOG_DEBUG, "NA->timeo = %d", (int) nap->timeo);
+  plog(XLOG_DEBUG, "NA->retrans = %d", (int) nap->retrans);
 
 #ifdef HAVE_FIELD_NFS_ARGS_T_ACREGMIN
-  plog(XLOG_DEBUG, "NA->acregmin = %d", nap->acregmin);
-  plog(XLOG_DEBUG, "NA->acregmax = %d", nap->acregmax);
-  plog(XLOG_DEBUG, "NA->acdirmin = %d", nap->acdirmin);
-  plog(XLOG_DEBUG, "NA->acdirmax = %d", nap->acdirmax);
+  plog(XLOG_DEBUG, "NA->acregmin = %d", (int) nap->acregmin);
+  plog(XLOG_DEBUG, "NA->acregmax = %d", (int) nap->acregmax);
+  plog(XLOG_DEBUG, "NA->acdirmin = %d", (int) nap->acdirmin);
+  plog(XLOG_DEBUG, "NA->acdirmax = %d", (int) nap->acdirmax);
 #endif /* HAVE_FIELD_NFS_ARGS_T_ACREGMIN */
 #ifdef MNTTAB_OPT_SYMTTL
   plog(XLOG_DEBUG, "NA->symttl = %d", nap->symttl);
